CubeTensor

Struct CubeTensor 

pub struct CubeTensor<R>
where R: CubeRuntime,
{ pub client: ComputeClient<R>, pub handle: Handle, pub meta: Box<Metadata>, pub device: <R as Runtime>::Device, pub dtype: DType, pub qparams: Option<QParams<QParamTensor>>, }
The basic tensor primitive struct.

Fields

client: ComputeClient<R>

Compute client for the runtime.

handle: Handle

The buffer where the data are stored.

meta: Box<Metadata>

The metadata of the tensor.

device: <R as Runtime>::Device

The device of the tensor.

dtype: DType

The datatype of the tensor.

qparams: Option<QParams<QParamTensor>>

Runtime quantization parameters, if applicable

Implementations

Source

impl<R> CubeTensor<R>
where R: CubeRuntime,

pub fn new( client: ComputeClient<R>, handle: Handle, metadata: Metadata, device: <R as Runtime>::Device, dtype: DType, ) -> CubeTensor<R>

Create a new standard tensor

pub fn new_contiguous( client: ComputeClient<R>, device: <R as Runtime>::Device, shape: Shape, handle: Handle, dtype: DType, ) -> CubeTensor<R>

Create a new tensor with a contiguous memory layout.

pub fn to_client( &mut self, client: ComputeClient<R>, device: <R as Runtime>::Device, ) -> CubeTensor<R>

Change the context of the current tensor and return the newly transferred tensor.

pub fn binding(self) -> TensorBinding<R>

Return the reference to a tensor handle.

pub fn elem_size(&self) -> usize

Returns the element size of this tensor

pub fn into_tensor_arg(self) -> TensorArg<R>

Return the reference to a tensor argument.

pub fn into_array_arg(self) -> ArrayArg<R>

Return the reference to an array argument.

pub fn as_tensor_alias(&self, input_pos: usize) -> TensorArg<R>

Returns a reference to the aliased tensor argument.

pub fn into_linear_view(self) -> ViewArg<usize, R>

Return a linear view of this tensor.

pub fn as_linear_view_alias(&self, input_pos: usize) -> ViewArg<usize, R>

Return an aliased linear view of this tensor

pub fn into_linear_view_like( self, reference: &CubeTensor<R>, ) -> ViewArg<usize, R>

Return a linear view broadcast to the reference tensor’s shape

pub fn required_address_type(&self) -> AddressType

Returns the address type required to index this tensor

pub fn try_scheme(&self) -> Option<&QuantScheme>

Return the QuantScheme if present

pub fn copy(&self) -> CubeTensor<R>

Copy the current tensor.

pub fn can_mut(&self) -> bool

Check if the tensor is safe to mutate.

pub fn assert_is_on_same_device(&self, other: &CubeTensor<R>)

Assert that both tensors are on the same device.

pub fn is_contiguous(&self) -> bool

Check if the current tensor is contiguous.

A tensor is contiguous if the elements are stored in memory if the strides in non-increasing order and the strides at position k is equal to the product of the shapes at all positions greater than k. However, all axes with a shape of 1 are ignored.

pub fn is_contiguous_buffer(&self) -> bool

Check if the current tensor has a contiguous backing buffer (no overlap and no empty memory regions within the shape).

pub fn is_nonoverlapping(&self) -> bool

Checks if the tensor is non-overlapping (can be safely written to).

Source

impl<R> CubeTensor<R>
where R: CubeRuntime,

pub fn new_quantized( client: ComputeClient<R>, handle: Handle, shape: Shape, device: <R as Runtime>::Device, strides: Strides, dtype: DType, qparams: QParams<QParamTensor>, ) -> CubeTensor<R>

Create a new quantized tensor

pub fn quantized_handles(&self) -> Option<(CubeTensor<R>, CubeTensor<R>)>

Returns the two tensors: (values, params) for a quantized tensor. For the values, native types that aren’t supported as a normal DType will be returned as an unsigned integer tensor representing the bits. Should be reconstructed using from_bits in kernels.

pub fn scales(&self) -> Option<CubeTensor<R>>

Construct a separate tensor for the quantization scales, if present